pub enum RunStatus {
Passed,
TestsFailed,
CompileFailed,
TestrunInterrupted,
GenericError,
}Expand description
The overall status of a test run.
Variants
Passed
The submission and tests compiled and all tests passed.
TestsFailed
The submission and tests compiled but some tests failed.
CompileFailed
The submission or tests did not compile.
TestrunInterrupted
The submission compiled but testrun was interrupted.
GenericError
For when no other status seems suitable, or the language plugin has suffered an internal error.