pub struct ExerciseDesc {
pub name: String,
pub tests: Vec<TestDesc>,
}Expand description
A description of an exercise.
Fields
name: StringThe name of the exercise to be shown to the user. Does not necessarily match or even contain the directory name.
tests: Vec<TestDesc>Descriptions of the tests that will be run for this exercise.
Implementations