pub struct ExercisePackagingConfiguration {
pub student_file_paths: HashSet<PathBuf>,
pub exercise_file_paths: HashSet<PathBuf>,
}Expand description
Represents configuration based on which submission may be packaged.
Fields
student_file_paths: HashSet<PathBuf>Student folders or files which are copied from submission.
exercise_file_paths: HashSet<PathBuf>Exercise folders or files which are copied from exercise template or clone.
Implementations