pub struct StyleValidationError {
pub column: u32,
pub line: u32,
pub message: String,
pub source_name: String,
}Expand description
A style validation error.
Fields
column: u32line: u32message: Stringsource_name: StringTrait Implementations
Sourceimpl Debug for StyleValidationError
impl Debug for StyleValidationError
Sourceimpl<'de> Deserialize<'de> for StyleValidationError
impl<'de> Deserialize<'de> for StyleValidationError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StyleValidationError
impl JsonSchema for StyleValidationError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StyleValidationError
impl PartialEq for StyleValidationError
Sourceimpl Serialize for StyleValidationError
impl Serialize for StyleValidationError
impl Eq for StyleValidationError
impl StructuralPartialEq for StyleValidationError