pub struct StyleValidationResult {
pub strategy: StyleValidationStrategy,
pub validation_errors: Option<HashMap<PathBuf, Vec<StyleValidationError>>>,
}Expand description
The result of a style check.
Fields
strategy: StyleValidationStrategyvalidation_errors: Option<HashMap<PathBuf, Vec<StyleValidationError>>>Trait Implementations
Sourceimpl Debug for StyleValidationResult
impl Debug for StyleValidationResult
Sourceimpl<'de> Deserialize<'de> for StyleValidationResult
impl<'de> Deserialize<'de> for StyleValidationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StyleValidationResult
impl JsonSchema for StyleValidationResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StyleValidationResult
impl PartialEq for StyleValidationResult
Sourceimpl Serialize for StyleValidationResult
impl Serialize for StyleValidationResult
impl Eq for StyleValidationResult
impl StructuralPartialEq for StyleValidationResult