pub struct TestDesc {
pub name: String,
pub points: Vec<String>,
}Expand description
A description of an exercise’s test case.
Fields
name: StringThe full name of the test.
If the language organises tests into suites or classes, it is customary to name the test as “class_name.method_name”.
points: Vec<String>The list of point names that passing this test may give.
To obtain a point X, the user must pass all exercises that require point X.
Implementations